pub struct Decoder<Sink, A = NonAtomic>{ /* private fields */ }Expand description
A TendrilSink adaptor that takes bytes, decodes them as the given
character encoding, while replacing any ill-formed byte sequences with
U+FFFD replacement characters, and emits Unicode (StrTendril).
This allocates new tendrils for encodings other than UTF-8.
Implementations